//
//  TestRewardedVC.m
//  SampleApp
//
//  Created by Pokkt on 17/02/16.
//  Copyright © 2016 Pokkt. All rights reserved.
//

#import "TestRewardedVC.h"
#import "AppDelegate.h"
#import "PokktManager.h"
#import "AdDelegate.h"
#import "PokktConfig.h"
#import "InAppPurchaseRequest.h"
#import <QuartzCore/QuartzCore.h>
#import "MBProgressHUD.h"

#define ErnedPoints @"Points"
#define userDefaluts [NSUserDefaults standardUserDefaults]

@interface TestRewardedVC ()

@property (nonatomic, strong) AppDelegate *appdelegate;
@property (nonatomic, strong) PokktConfig *pokktConfig;
@property (nonatomic) float point;


@end

@implementation TestRewardedVC
@synthesize screenName,isRewardedScreen;


- (void)viewDidLoad {
    [super viewDidLoad];
    self.point = 0.0f;
    // Do any additional setup after loading the view from its nib.
    [self setCornerRadius];
    self.appdelegate = [UIApplication sharedApplication].delegate;
    UIDeviceOrientation  m_CurrentOrientation = [[UIDevice currentDevice] orientation];
    if (m_CurrentOrientation == UIDeviceOrientationLandscapeLeft || m_CurrentOrientation == UIDeviceOrientationLandscapeRight ) {
        [scroll setContentSize:CGSizeMake(250, 150)];
    }
    [[UIDevice currentDevice] beginGeneratingDeviceOrientationNotifications];
    
    [[NSNotificationCenter defaultCenter] addObserver: self selector: @selector(deviceOrientationDidChange:) name: UIDeviceOrientationDidChangeNotification object: nil];
    
    self.adConfig = [[AdConfig alloc] init];
    self.adConfig.screenName = self.screenName;
    self.adConfig.isRewarded = self.isRewardedScreen;
    self.adConfig.shouldAllowSkip = YES;
    self.adConfig.defaultSkipTime = 10;

    [self updatepointsEarned];
    
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(showToast:)
                                                 name:@"toastMessage"
                                               object:nil];

}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

-(void)viewWillAppear:(BOOL)animated{
    [super viewWillAppear:animated];
    [self showButton:NO];
}

-(void)viewWillDisappear:(BOOL)animated{
    [super viewWillDisappear:animated];
    [self.navigationController setNavigationBarHidden:NO];    // it shows
    
}

-(void)setCornerRadius
{
    startCaching.layer.cornerRadius = 10; // this value vary as per your desire
    startCaching.clipsToBounds = YES;
    
    playAdBtn.layer.cornerRadius = 10; // this value vary as per your desire
    playAdBtn.clipsToBounds = YES;
    
}

#pragma mark - Button Action

- (IBAction)videoButtonActions:(UIButton *)sender {
    if (sender.tag == 1)
    {
        [self checkVideoCache];
        [playAdBtn setHidden:YES];
        InAppPurchaseRequest *request = [[InAppPurchaseRequest alloc]init];
        request.productCurrency = @"E";
        request.productDescription = @"Second";
        request.productIdentifier = @"ABC123";
        request.productPrice = @"500";
        request.productTitle = @"Mobile App";
        [PokktManager trackIAP:request];
        
    }
    else if (sender.tag == 2)
    {
        [PokktManager checkAdAvailability:self.adConfig];
    }
}

- (void)checkVideoCache
{
    [PokktManager cacheAd:self.adConfig];
}

- (void)showButton:(BOOL)show {
    [playAdBtn setHidden:NO];
    if (!show) {
        if (self.isRewardedScreen) {
            [playAdBtn setTitle:@"Play Rewarded Ad(Without Caching)" forState:UIControlStateNormal];
        }
        else
        {
            [playAdBtn setTitle:@"Play NonRewarded Ad(Without Caching)" forState:UIControlStateNormal];
        }
        
    }
    else
    {
        if (self.isRewardedScreen) {
            [playAdBtn setTitle:@"Play Rewarded Ad(With Caching)" forState:UIControlStateNormal];
        }
        else
        {
            [playAdBtn setTitle:@"Play NonRewarded Ad(With Caching)" forState:UIControlStateNormal]; 
        }
       
    }
}

#pragma mark - Private Methods

- (void)updatepointsEarned {
    if([userDefaluts objectForKey:ErnedPoints])
    {
        self.point = [[userDefaluts objectForKey:ErnedPoints] floatValue];
        self.pointNumLbl.text = [NSString stringWithFormat:@"Points earned : %f",self.point];
    }
}

- (void)showAlertWithMessage:(NSString *)msg {
    
    UIAlertView *alert = [[UIAlertView alloc]initWithTitle:@"" message:msg delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil];
    [alert show];
}

#pragma mark - Pokkt Delegates

- (void)onPokktInitialised:(BOOL)isReady
{
    
    if (isReady)
    {
        NSLog(@"PokktSDK is ready");
    }
    else
    {
        NSLog(@"PokktSDK is not ready");
        [self showAlertWithMessage:@"PokktSDK is not ready"];
    }
}

- (void)onAdAvailabilityStatus:(AdConfig *)adConfig withAvailability:(BOOL)isAdAvailable
{
    NSLog(@"Ad is available");
    if (isAdAvailable)
    {
        [PokktManager showAd:self.adConfig presentingViewController:self];
    }
    else
    {
        NSString *str = @"";
        if (adConfig.isRewarded) {
            str = @"rewarded";
        }
        else
        {
            str = @"non rewarded";
        }
        [self showAlertWithMessage:[NSString stringWithFormat:@"%@ %@ ad not available",adConfig.screenName, str]];
    }
}

- (void)onAdCachingCompleted:(AdConfig *)adConfig withReward:(float)reward
{
    [self showButton:YES];
}

- (void)onAdCachingFailed:(AdConfig *)adConfig withErrorMessage:(NSString *)errorMessage
{
    NSString *str = @"";
    if (adConfig.isRewarded) {
        str = @"rewarded";
    }
    else
    {
        str = @"non rewarded";
    }
     [self showAlertWithMessage:[NSString stringWithFormat:@"%@ %@ ad not available",adConfig.screenName, str]];
    [self showButton:NO];
}

- (void)onAdClosed: (AdConfig *)adConfig
{
    [self showAlertWithMessage:@"Video is closed"];
    [self showButton:NO];
    self.navigationController.navigationBarHidden = NO;
}

- (void)onAdCompleted:(AdConfig *)adConfig
{
    [self showAlertWithMessage:@"Video is completed"];
}

- (void)onAdDisplayed:(AdConfig *)adConfig
{
    self.navigationController.navigationBarHidden = YES;
    [self showAlertWithMessage:@"Video is displayed"];
}

- (void)onAdGratified:(AdConfig *)adConfig withReward:(float)reward
{
    if([userDefaluts objectForKey:ErnedPoints])
    {
        self.point = [[userDefaluts objectForKey:ErnedPoints] floatValue];
    }
    if (reward > 0)
    {
        self.point += reward;
        [userDefaluts setValue:[NSString stringWithFormat:@"%f",self.point] forKey:ErnedPoints];
        [userDefaluts synchronize];
        [self updatepointsEarned];
    }
    
}

- (void)onAdSkipped:(AdConfig *)adConfig
{
    [self showAlertWithMessage:@"Video is skip"];
}

#pragma mark - Orienation

- (UIInterfaceOrientationMask)supportedInterfaceOrientations
{
    if (self.appdelegate.deviceType == iPhone4s || self.appdelegate.deviceType == iPhone5 || self.appdelegate.deviceType == iPhone5s) {
        return UIInterfaceOrientationMaskPortrait;
    }
    return UIInterfaceOrientationMaskAll;
}

- (void)deviceOrientationDidChange:(NSNotification *)notification
{
    UIDeviceOrientation  m_CurrentOrientation = [[UIDevice currentDevice] orientation];
    if (m_CurrentOrientation == UIDeviceOrientationLandscapeLeft || m_CurrentOrientation == UIDeviceOrientationLandscapeRight ) {
        [scroll setContentSize:CGSizeMake(250, 150)];
    }
    else if (m_CurrentOrientation == UIDeviceOrientationPortrait || m_CurrentOrientation == UIDeviceOrientationPortraitUpsideDown)
    {
        [scroll setContentSize:CGSizeMake(250, 200)];
    }
}

-(void)showToast:(NSNotification *)note
{
    NSString *message = note.object;
    
    if (message != nil && message.length > 0)
    {
        [PokktManager showToast:message presentingViewController:self];
    }
}



@end
